==> we-node-client-grpc-java-0.3.0-sources.jar: com/wavesenterprise/protobuf/service/contract/PkiServiceGrpc.java <==
package com.wavesenterprise.protobuf.service.contract;

import static io.grpc.MethodDescriptor.generateFullMethodName;
import static io.grpc.stub.ClientCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ClientCalls.asyncClientStreamingCall;
import static io.grpc.stub.ClientCalls.asyncServerStreamingCall;
import static io.grpc.stub.ClientCalls.asyncUnaryCall;
import static io.grpc.stub.ClientCalls.blockingServerStreamingCall;
import static io.grpc.stub.ClientCalls.blockingUnaryCall;
import static io.grpc.stub.ClientCalls.futureUnaryCall;
import static io.grpc.stub.ServerCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ServerCalls.asyncClientStreamingCall;
import static io.grpc.stub.ServerCalls.asyncServerStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnaryCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.16.0)",
    comments = "Source: contract/contract_pki_service.proto")
public final class PkiServiceGrpc {

  private PkiServiceGrpc() {}

  public static final String SERVICE_NAME = "wavesenterprise.PkiService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.contract.PkiSignRequest,
      com.wavesenterprise.protobuf.service.contract.PkiSignResponse> getSignMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Sign",
      requestType = com.wavesenterprise.protobuf.service.contract.PkiSignRequest.class,
      responseType = com.wavesenterprise.protobuf.service.contract.PkiSignResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.contract.PkiSignRequest,
      com.wavesenterprise.protobuf.service.contract.PkiSignResponse> getSignMethod() {
    io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.contract.PkiSignRequest, com.wavesenterprise.protobuf.service.contract.PkiSignResponse> getSignMethod;
    if ((getSignMethod = PkiServiceGrpc.getSignMethod) == null) {
      synchronized (PkiServiceGrpc.class) {
        if ((getSignMethod = PkiServiceGrpc.getSignMethod) == null) {
          PkiServiceGrpc.getSignMethod = getSignMethod = 
              io.grpc.MethodDescriptor.<com.wavesenterprise.protobuf.service.contract.PkiSignRequest, com.wavesenterprise.protobuf.service.contract.PkiSignResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(
                  "wavesenterprise.PkiService", "Sign"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.contract.PkiSignRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.contract.PkiSignResponse.getDefaultInstance()))
                  .setSchemaDescriptor(new PkiServiceMethodDescriptorSupplier("Sign"))
                  .build();
          }
        }
     }
     return getSignMethod;
  }

  private static volatile io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest,
      com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse> getVerifyMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Verify",
      requestType = com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest.class,
      responseType = com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest,
      com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse> getVerifyMethod() {
    io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest, com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse> getVerifyMethod;
    if ((getVerifyMethod = PkiServiceGrpc.getVerifyMethod) == null) {
      synchronized (PkiServiceGrpc.class) {
        if ((getVerifyMethod = PkiServiceGrpc.getVerifyMethod) == null) {
          PkiServiceGrpc.getVerifyMethod = getVerifyMethod = 
              io.grpc.MethodDescriptor.<com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest, com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(
                  "wavesenterprise.PkiService", "Verify"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse.getDefaultInstance()))
                  .setSchemaDescriptor(new PkiServiceMethodDescriptorSupplier("Verify"))
                  .build();
          }
        }
     }
     return getVerifyMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static PkiServiceStub newStub(io.grpc.Channel channel) {
    return new PkiServiceStub(channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static PkiServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    return new PkiServiceBlockingStub(channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static PkiServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    return new PkiServiceFutureStub(channel);
  }

  /**
   */
  public static abstract class PkiServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void sign(com.wavesenterprise.protobuf.service.contract.PkiSignRequest request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.contract.PkiSignResponse> responseObserver) {
      asyncUnimplementedUnaryCall(getSignMethod(), responseObserver);
    }

    /**
     */
    public void verify(com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse> responseObserver) {
      asyncUnimplementedUnaryCall(getVerifyMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getSignMethod(),
            asyncUnaryCall(
              new MethodHandlers<
                com.wavesenterprise.protobuf.service.contract.PkiSignRequest,
                com.wavesenterprise.protobuf.service.contract.PkiSignResponse>(
                  this, METHODID_SIGN)))
          .addMethod(
            getVerifyMethod(),
            asyncUnaryCall(
              new MethodHandlers<
                com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest,
                com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse>(
                  this, METHODID_VERIFY)))
          .build();
    }
  }

  /**
   */
  public static final class PkiServiceStub extends io.grpc.stub.AbstractStub<PkiServiceStub> {
    private PkiServiceStub(io.grpc.Channel channel) {
      super(channel);
    }

    private PkiServiceStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PkiServiceStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new PkiServiceStub(channel, callOptions);
    }

    /**
     */
    public void sign(com.wavesenterprise.protobuf.service.contract.PkiSignRequest request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.contract.PkiSignResponse> responseObserver) {
      asyncUnaryCall(
          getChannel().newCall(getSignMethod(), getCallOptions()), request, responseObserver);
    }

    /**
     */
    public void verify(com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse> responseObserver) {
      asyncUnaryCall(
          getChannel().newCall(getVerifyMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class PkiServiceBlockingStub extends io.grpc.stub.AbstractStub<PkiServiceBlockingStub> {
    private PkiServiceBlockingStub(io.grpc.Channel channel) {
      super(channel);
    }

    private PkiServiceBlockingStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PkiServiceBlockingStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new PkiServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public com.wavesenterprise.protobuf.service.contract.PkiSignResponse sign(com.wavesenterprise.protobuf.service.contract.PkiSignRequest request) {
      return blockingUnaryCall(
          getChannel(), getSignMethod(), getCallOptions(), request);
    }

    /**
     */
    public com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse verify(com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest request) {
      return blockingUnaryCall(
          getChannel(), getVerifyMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class PkiServiceFutureStub extends io.grpc.stub.AbstractStub<PkiServiceFutureStub> {
    private PkiServiceFutureStub(io.grpc.Channel channel) {
      super(channel);
    }

    private PkiServiceFutureStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PkiServiceFutureStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new PkiServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<com.wavesenterprise.protobuf.service.contract.PkiSignResponse> sign(
        com.wavesenterprise.protobuf.service.contract.PkiSignRequest request) {
      return futureUnaryCall(
          getChannel().newCall(getSignMethod(), getCallOptions()), request);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse> verify(
        com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest request) {
      return futureUnaryCall(
          getChannel().newCall(getVerifyMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_SIGN = 0;
  private static final int METHODID_VERIFY = 1;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final PkiServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(PkiServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_SIGN:
          serviceImpl.sign((com.wavesenterprise.protobuf.service.contract.PkiSignRequest) request,
              (io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.contract.PkiSignResponse>) responseObserver);
          break;
        case METHODID_VERIFY:
          serviceImpl.verify((com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest) request,
              (io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class PkiServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    PkiServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return com.wavesenterprise.protobuf.service.contract.ContractPkiService.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("PkiService");
    }
  }

  private static final class PkiServiceFileDescriptorSupplier
      extends PkiServiceBaseDescriptorSupplier {
    PkiServiceFileDescriptorSupplier() {}
  }

  private static final class PkiServiceMethodDescriptorSupplier
      extends PkiServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    PkiServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (PkiServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new PkiServiceFileDescriptorSupplier())
              .addMethod(getSignMethod())
              .addMethod(getVerifyMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> we-node-client-grpc-java-2.0.0-sources.jar: com/wavesenterprise/protobuf/service/contract/PkiServiceGrpc.java <==
package com.wavesenterprise.protobuf.service.contract;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.64.0)",
    comments = "Source: contract/contract_pki_service.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class PkiServiceGrpc {

  private PkiServiceGrpc() {}

  public static final java.lang.String SERVICE_NAME = "wavesenterprise.PkiService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.contract.PkiSignRequest,
      com.wavesenterprise.protobuf.service.contract.PkiSignResponse> getSignMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Sign",
      requestType = com.wavesenterprise.protobuf.service.contract.PkiSignRequest.class,
      responseType = com.wavesenterprise.protobuf.service.contract.PkiSignResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.contract.PkiSignRequest,
      com.wavesenterprise.protobuf.service.contract.PkiSignResponse> getSignMethod() {
    io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.contract.PkiSignRequest, com.wavesenterprise.protobuf.service.contract.PkiSignResponse> getSignMethod;
    if ((getSignMethod = PkiServiceGrpc.getSignMethod) == null) {
      synchronized (PkiServiceGrpc.class) {
        if ((getSignMethod = PkiServiceGrpc.getSignMethod) == null) {
          PkiServiceGrpc.getSignMethod = getSignMethod =
              io.grpc.MethodDescriptor.<com.wavesenterprise.protobuf.service.contract.PkiSignRequest, com.wavesenterprise.protobuf.service.contract.PkiSignResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Sign"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.contract.PkiSignRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.contract.PkiSignResponse.getDefaultInstance()))
              .setSchemaDescriptor(new PkiServiceMethodDescriptorSupplier("Sign"))
              .build();
        }
      }
    }
    return getSignMethod;
  }

  private static volatile io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest,
      com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse> getVerifyMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Verify",
      requestType = com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest.class,
      responseType = com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest,
      com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse> getVerifyMethod() {
    io.grpc.MethodDescriptor<com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest, com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse> getVerifyMethod;
    if ((getVerifyMethod = PkiServiceGrpc.getVerifyMethod) == null) {
      synchronized (PkiServiceGrpc.class) {
        if ((getVerifyMethod = PkiServiceGrpc.getVerifyMethod) == null) {
          PkiServiceGrpc.getVerifyMethod = getVerifyMethod =
              io.grpc.MethodDescriptor.<com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest, com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Verify"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse.getDefaultInstance()))
              .setSchemaDescriptor(new PkiServiceMethodDescriptorSupplier("Verify"))
              .build();
        }
      }
    }
    return getVerifyMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static PkiServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<PkiServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<PkiServiceStub>() {
        @java.lang.Override
        public PkiServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new PkiServiceStub(channel, callOptions);
        }
      };
    return PkiServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static PkiServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<PkiServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<PkiServiceBlockingStub>() {
        @java.lang.Override
        public PkiServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new PkiServiceBlockingStub(channel, callOptions);
        }
      };
    return PkiServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static PkiServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<PkiServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<PkiServiceFutureStub>() {
        @java.lang.Override
        public PkiServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new PkiServiceFutureStub(channel, callOptions);
        }
      };
    return PkiServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     */
    default void sign(com.wavesenterprise.protobuf.service.contract.PkiSignRequest request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.contract.PkiSignResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getSignMethod(), responseObserver);
    }

    /**
     */
    default void verify(com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getVerifyMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service PkiService.
   */
  public static abstract class PkiServiceImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return PkiServiceGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service PkiService.
   */
  public static final class PkiServiceStub
      extends io.grpc.stub.AbstractAsyncStub<PkiServiceStub> {
    private PkiServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PkiServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new PkiServiceStub(channel, callOptions);
    }

    /**
     */
    public void sign(com.wavesenterprise.protobuf.service.contract.PkiSignRequest request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.contract.PkiSignResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getSignMethod(), getCallOptions()), request, responseObserver);
    }

    /**
     */
    public void verify(com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getVerifyMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service PkiService.
   */
  public static final class PkiServiceBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<PkiServiceBlockingStub> {
    private PkiServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PkiServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new PkiServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public com.wavesenterprise.protobuf.service.contract.PkiSignResponse sign(com.wavesenterprise.protobuf.service.contract.PkiSignRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getSignMethod(), getCallOptions(), request);
    }

    /**
     */
    public com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse verify(com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getVerifyMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service PkiService.
   */
  public static final class PkiServiceFutureStub
      extends io.grpc.stub.AbstractFutureStub<PkiServiceFutureStub> {
    private PkiServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PkiServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new PkiServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<com.wavesenterprise.protobuf.service.contract.PkiSignResponse> sign(
        com.wavesenterprise.protobuf.service.contract.PkiSignRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getSignMethod(), getCallOptions()), request);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse> verify(
        com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getVerifyMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_SIGN = 0;
  private static final int METHODID_VERIFY = 1;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_SIGN:
          serviceImpl.sign((com.wavesenterprise.protobuf.service.contract.PkiSignRequest) request,
              (io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.contract.PkiSignResponse>) responseObserver);
          break;
        case METHODID_VERIFY:
          serviceImpl.verify((com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest) request,
              (io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getSignMethod(),
          io.grpc.stub.ServerCalls.asyncUnaryCall(
            new MethodHandlers<
              com.wavesenterprise.protobuf.service.contract.PkiSignRequest,
              com.wavesenterprise.protobuf.service.contract.PkiSignResponse>(
                service, METHODID_SIGN)))
        .addMethod(
          getVerifyMethod(),
          io.grpc.stub.ServerCalls.asyncUnaryCall(
            new MethodHandlers<
              com.wavesenterprise.protobuf.service.contract.PkiVerifyRequest,
              com.wavesenterprise.protobuf.service.contract.PkiVerifyResponse>(
                service, METHODID_VERIFY)))
        .build();
  }

  private static abstract class PkiServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    PkiServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return com.wavesenterprise.protobuf.service.contract.ContractPkiService.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("PkiService");
    }
  }

  private static final class PkiServiceFileDescriptorSupplier
      extends PkiServiceBaseDescriptorSupplier {
    PkiServiceFileDescriptorSupplier() {}
  }

  private static final class PkiServiceMethodDescriptorSupplier
      extends PkiServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    PkiServiceMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (PkiServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new PkiServiceFileDescriptorSupplier())
              .addMethod(getSignMethod())
              .addMethod(getVerifyMethod())
              .build();
        }
      }
    }
    return result;
  }
}
